# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.
"""
 Test suite for Quacpac TK examples
"""

import pytest
from . import OETestCase, check_license


@pytest.mark.skipif(check_license('quacpac') is False, reason='QUACPAC license not found')
class TestQuacpac(OETestCase):

    def test_example3(self):
        script = self.run_example(
            '{0}/quacpac/getreasonabletautomers.py'.format(self.EXAMPLES_DIR),
            '{0}/data.smi'.format(self.DATA_DIR),
            'enumerate_out.smi')
        self.assertFalse(script.returncode)
