#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# This example reads in a reference molecule and a few fit
# molecules, performs overlay optimization, sorts the results
# in Tanimoto order, and shows the single best result.
# With the default options, OEOverlay optimizes both shape and color.


import sys

from openeye import oechem
from openeye import oeshape


def main(argv=[__name__]):
    overlayOpts = oeshape.OEFlexiOverlayOptions()
    opts = oechem.OERefInputAppOptions(overlayOpts, "FlexiOverlay", oechem.OEFileStringType_Mol3D,
                                       oechem.OEFileStringType_Mol3D, oechem.OEFileStringType_Mol3D, "-refmol")
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    overlayOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    rfs = oechem.oemolistream()
    if not rfs.open(opts.GetRefFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetRefFile())

    ofs = oechem.oemolostream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    refmol = oechem.OEMol()
    oechem.OEReadMolecule(rfs, refmol)
    print("Ref. Title:", refmol.GetTitle())

    overlay = oeshape.OEFlexiOverlay(overlayOpts)
    overlay.SetupRef(refmol)

    for fitmol in ifs.GetOEMols():
        results = overlay.Overlay(fitmol)
        for res, conf in zip(results, fitmol.GetConfs()):
            print("Fit Title: %-4s Tanimoto Combo: %.2f Energy: %2f"
                  % (fitmol.GetTitle(), res.GetTanimotoCombo(), res.GetInternalEnergy()))
            oechem.OESetSDData(conf, "Tanimoto Combo", "%.2f" % res.GetTanimotoCombo())
            oechem.OESetSDData(conf, "Energy", "%.2f" % res.GetInternalEnergy())
        oechem.OEWriteMolecule(ofs, fitmol)



if __name__ == "__main__":
    sys.exit(main(sys.argv))
