#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oemolprop

if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <molfile>" % sys.argv[0])

ifs = oechem.oemolistream()
if not ifs.open(sys.argv[1]):
    oechem.OEThrow.Fatal("Unable to open %s for reading" % sys.argv[1])

mol = oechem.OEGraphMol()
if not oechem.OEReadMolecule(ifs, mol):
    oechem.OEThrow.Fatal("Unable to read molecule from %s" % sys.argv[1])

# @ <SNIPPET-ATOMS>
atomPSA = oechem.OEFloatArray(mol.GetMaxAtomIdx())
psa = oemolprop.OEGet2dPSA(mol, atomPSA)

print("PSA =", psa)
for atom in mol.GetAtoms():
    idx = atom.GetIdx()
    print(idx, atomPSA[idx])
# @ </SNIPPET-ATOMS>
