#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.
import sys

from openeye import oechem
from openeye import oesitehopper


def main(argv):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <shdb file> <du directory>" % argv[0])

    shdb = oesitehopper.OESiteHopperDatabase()
    if not shdb.Open(argv[1], oesitehopper.OESiteHopperDatabaseMode_CREATE):
        oechem.OEThrow.Error(f"unable to open {argv[1]}.")
        return 1

    tracer = oechem.OEConsoleProgressTracer()
    shdb.AddDirectory(argv[2], 0, tracer)



if __name__ == "__main__":
    sys.exit(main(sys.argv))