#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oeff
from openeye import oeomega

mol = oechem.OEMol()
oechem.OESmilesToMol(mol, "C1CCCCC1N(=O)CCS")

# @ <SNIPPET-GPUOmega-sparse>
omegaOpts = oeomega.OEOmegaOptions()
omegaOpts.GetTorDriveOptions().SetUseGPU(False)
omega = oeomega.OEOmega(omegaOpts)
omega(mol)
# @ </SNIPPET-GPUOmega-sparse>

# @ <SNIPPET-GPUOmega-dense>
omegaOpts = oeomega.OEOmegaOptions(oeomega.OEOmegaSampling_Dense)
if oeomega.OEOmegaIsGPUReady():
    omegaOpts.GetTorDriveOptions().SetForceField(oeff.OEMMFFSheffieldFFType_MMFF94Smod_NOESTAT)
    omegaOpts.GetMolBuilderOptions().SetSampleHydrogens(False)
omega = oeomega.OEOmega(omegaOpts)
omega(mol)
# @ </SNIPPET-GPUOmega-dense>
