#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeszybki

def main(argv=[__name__]):
    torOpts = oeszybki.OETorsionScanOptions()
    opts = oechem.OESimpleAppOptions(torOpts, "TorsionScan",oechem.OEFileStringType_Mol3D,
                                     oechem.OEFileStringType_Mol3D)

    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    torOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    mol = oechem.OEMol()
    oechem.OEReadMolecule(ifs, mol)

    outmol = oechem.OEMol()

    for tor in oechem.OEGetTorsions(mol):
        print("Torsion: %d %d %d %d" %
              (tor.a.GetIdx(), tor.b.GetIdx(), tor.c.GetIdx(), tor.d.GetIdx()))
        for res in oeszybki.OETorsionScan(outmol, mol, tor, torOpts):
            print("%.2f %.2f" % (res.GetAngle(), res.GetEnergy()))

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))
