#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


def ImportMolecule(filename):

    ifs = oechem.oemolistream()
    if not ifs.open(filename):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % filename)

    mol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, mol):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % filename)
    return mol


if len(sys.argv) != 3:
    oechem.OEThrow.Usage("%s <ref> <fit>" % sys.argv[0])

refmol3D = ImportMolecule(sys.argv[1])
fitmol3D = ImportMolecule(sys.argv[2])

# @ <SNIPPET-PREPARE-ALIGNED-DEPICTION-FROM-3D>
refmol2D = oechem.OEGraphMol(refmol3D)
oegrapheme.OEPrepareDepictionFrom3D(refmol2D)

fitmol2D = oechem.OEGraphMol(fitmol3D)
oegrapheme.OEPrepareAlignedDepictionFrom3D(fitmol2D, fitmol3D, refmol2D, refmol3D)

width, height = 300, 300
opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
refscale = oedepict.OEGetMoleculeScale(refmol2D, opts)
fitscale = oedepict.OEGetMoleculeScale(fitmol2D, opts)
opts.SetScale(min(refscale, fitscale))

refdisp = oedepict.OE2DMolDisplay(refmol2D, opts)
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-ref-2D.png", refdisp)

fitdisp = oedepict.OE2DMolDisplay(fitmol2D, opts)
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-fit-2D.png", fitdisp)

# @ </SNIPPET-PREPARE-ALIGNED-DEPICTION-FROM-3D>
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-ref-2D.pdf", refdisp)
oedepict.OERenderMolecule("OEPrepareAlignedDepictionFrom3D-fit-2D.pdf", fitdisp)
