#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem


def main(argv=[__name__]):
    kernel = oechem.OESquareMatrix(4)
    kernel.SetRowData(0, [2686.9, 549.35, 509.31, 456.37])
    kernel.SetRowData(1, [549.12, 2815.15, 2433.03, 496.09])
    kernel.SetRowData(2, [509.11, 2432.17, 2804.49, 356.28])
    kernel.SetRowData(3, [456.36, 496.24, 356.27, 3643.08])
    response = [4.25, 6.62, 5.28, 8.10]

    pls = oechem.OEKernelPLS()
    pls.Fit(kernel, response, 1);
    pred_value = pls.Predict([2686.9, 549.35, 509.31, 456.37]);
    print("Actual: ", 4.25, " predicted: ", pred_value)
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))
