#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.
import sys

from openeye import oechem
from openeye import oesitehopper

import signal
signal.signal(signal.SIGINT, signal.SIG_DFL)


def main(argv):
    if len(argv) != 4:
        oechem.OEThrow.Usage("%s <shdb> <query du> <hits oedu>" % argv[0])

    shdb = oesitehopper.OESiteHopperDatabase()
    if not shdb.Open(argv[1], oesitehopper.OESiteHopperDatabaseMode_SEARCH):
        oechem.OEThrow.Error(f"unable to open {argv[1]}.")
        return 1

    du = oechem.OEDesignUnit()
    if not oechem.OEReadDesignUnit(argv[2], du):
        oechem.OEThrow.Error(f"unable to read OEDesignUnit from {argv[2]}")

    ofs = oechem.oeofstream()
    if not ofs.open(argv[3]):
        oechem.OEThrow.Fatal(f"unable to open {argv[3]} for writing hits.")

    oesitehopper.OEAddPatchSurface(du, shdb.GetOptions().GetPatchOptions())
    oechem.OEWriteDesignUnit(ofs, du)

    search = oesitehopper.OESiteHopperSearch(shdb)

    tracer = oechem.OEConsoleProgressTracer()
    opts = oesitehopper.OESiteHopperSearchOptions()
    opts.SetNormalizeAndRescore(True)
    opts.SetMaxHits(25)

    score: oesitehopper.OESiteHopperScore
    for score in search.Search(du, opts, tracer):
        print(score.GetRank(), score.GetTitle(), score.GetPatchScore())
        hit_du = score.GetDesignUnit()
        oesitehopper.OESetProteinSDData(hit_du, score)
        oechem.OEWriteDesignUnit(ofs, hit_du)


if __name__ == "__main__":
    sys.exit(main(sys.argv))
