#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1cc(N)cc(S(=O)(=O)O)c1")
oedepict.OEPrepareDepiction(mol)

width, height = 300, 200

opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
disp = oedepict.OE2DMolDisplay(mol, opts)

pred = oechem.OEIsAromaticBond()
for bond in mol.GetBonds(pred):
    # @ <SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAY>
    bdisp = disp.GetBondDisplay(bond)
    if bdisp is not None and bdisp.IsVisible():
        # do something
        pass
    # @ </SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAY>

# @ <SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAYS-PREDICATE>
for bdisp in disp.GetBondDisplays(oechem.OEIsAromaticBond()):
    if bdisp.IsVisible():
        # do something
        pass
# @ </SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAYS-PREDICATE>
