#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem


def main(argv=[__name__]):
    if len(argv) != 2:
        oechem.OEThrow.Usage("ToggleInterContour.py <receptor>")

    du = oechem.OEDesignUnit()
    if not oechem.OEReadDesignUnit(argv[1], du):
        oechem.OEThrow.Fatal("Cannot read receptor du file")

    if not du.HasReceptor():
        oechem.OEThrow.Fatal("Design unit %s does not have a receptor" % du.GetTitle())

    # @ <SNIPPET-TOGGLE-INNER-CONTOUR-1>
    receptor = du.GetReceptor()
    innerContourLevel = receptor.GetInnerContourLevel()
    receptor.SetInnerContourLevel(-innerContourLevel)
    # @ </SNIPPET-TOGGLE-INNER-CONTOUR-1>

    if innerContourLevel > 0.0:
        oechem.OEThrow.Info("Toggling inner contour off")
    else:
        oechem.OEThrow.Info("Toggling inner contour on")

    if not oechem.OEWriteDesignUnit(argv[1], du):
        oechem.OEThrow.Fatal("Unable to write receptor")


if __name__ == "__main__":
    sys.exit(main(sys.argv))
