#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeomega


def main(argv=[__name__]):
    buildOpts = oeomega.OEMacrocycleBuilderOptions()
    buildOpts.SetParameterVisibility(oechem.OEParamVisibility_Hidden)
    buildOpts.SetParameterVisibility("-seed", oechem.OEParamVisibility_Simple)
    buildOpts.SetParameterVisibility("-dielectric_constant", oechem.OEParamVisibility_Simple)

    inType = oechem.OEFileStringType_Mol
    outType = oechem.OEFileStringType_Mol3D
    opts = oechem.OESimpleAppOptions(buildOpts, "macrocycle_builder", inType, outType)
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0

    buildOpts.UpdateValues(opts)
    #builder = oeomega.OEMacrocycleBuilder(buildOpts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    ofs = oechem.oemolostream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    for mol in ifs.GetOEMols():
        oechem.OEThrow.Info("Title: %s" % mol.GetTitle())
        itlimit = 1000
        itnum = 0
        ret_code = oeomega.OEOmegaReturnCode_Failed
        while itnum <= itlimit:
            builder = oeomega.OEMacrocycleBuilder(buildOpts)
            ret_code = builder.Build(mol)
            if ret_code == oeomega.OEOmegaReturnCode_Success:
                oechem.OEWriteMolecule(ofs, mol)
                break
            else:
                buildOpts.SetRandomSeed(buildOpts.GetRandomSeed()+1)
            ++itnum
        if ret_code != oeomega.OEOmegaReturnCode_Success:
            oechem.OEThrow.Warning("%s: %s" % (mol.GetTitle(), oeomega.OEGetOmegaError(ret_code)))

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))
